@@ -88,40 +88,25 @@ struct device_radix_sort_onesweep_benchmark : public config_autotune_interface
     static constexpr unsigned int batch_size  = 10;
     static constexpr unsigned int warmup_size = 5;
 
-    static std::vector<Key> generate_keys(size_t size, unsigned int seed)
-    {
-        using key_type = Key;
-
-        if(std::is_floating_point<key_type>::value)
-        {
-            return get_random_data<key_type>(size,
-                                             static_cast<key_type>(-1000),
-                                             static_cast<key_type>(1000),
-                                             seed,
-                                             size);
-        }
-        else
-        {
-            return get_random_data<key_type>(size,
-                                             std::numeric_limits<key_type>::min(),
-                                             std::numeric_limits<key_type>::max(),
-                                             seed,
-                                             size);
-        }
-    }
-
     // keys benchmark
     template<typename val = Value>
     auto do_run(benchmark::State&   state,
-                size_t              size,
+                size_t              bytes,
                 const managed_seed& seed,
                 hipStream_t         stream) const ->
         typename std::enable_if<std::is_same<val, ::rocprim::empty_type>::value, void>::type
     {
-        auto keys_input = generate_keys(size, seed.get_0());
-
         using key_type = Key;
 
+        // Calculate the number of elements 
+        size_t size = bytes / sizeof(key_type);
+
+        std::vector<key_type> keys_input
+            = get_random_data<key_type>(size,
+                                        generate_limits<key_type>::min(),
+                                        generate_limits<key_type>::max(),
+                                        seed.get_0());
+
         key_type* d_keys_input;
         key_type* d_keys_output;
         HIP_CHECK(hipMalloc(reinterpret_cast<void**>(&d_keys_input), size * sizeof(key_type)));
@@ -232,16 +217,23 @@ struct device_radix_sort_onesweep_benchmark : public config_autotune_interface
     // pairs benchmark
     template<typename val = Value>
     auto do_run(benchmark::State&   state,
-                size_t              size,
+                size_t              bytes,
                 const managed_seed& seed,
                 hipStream_t         stream) const ->
         typename std::enable_if<!std::is_same<val, ::rocprim::empty_type>::value, void>::type
     {
-        auto keys_input = generate_keys(size, seed.get_0());
-
         using key_type   = Key;
         using value_type = Value;
 
+        // Calculate the number of elements 
+        size_t size = bytes / sizeof(key_type);
+
+        std::vector<key_type> keys_input
+            = get_random_data<key_type>(size,
+                                        generate_limits<key_type>::min(),
+                                        generate_limits<key_type>::max(),
+                                        seed.get_0());
+
         std::vector<value_type> values_input(size);
         for(size_t i = 0; i < size; i++)
         {
@@ -457,11 +449,11 @@ struct device_radix_sort_onesweep_benchmark_generator
     #define CREATE_RADIX_SORT_BENCHMARK(...)                                  \
         {                                                                     \
             const device_radix_sort_onesweep_benchmark<__VA_ARGS__> instance; \
-            REGISTER_BENCHMARK(benchmarks, size, seed, stream, instance);     \
+            REGISTER_BENCHMARK(benchmarks, bytes, seed, stream, instance);     \
         }
 
 inline void add_sort_keys_benchmarks(std::vector<benchmark::internal::Benchmark*>& benchmarks,
-                                     size_t                                        size,
+                                     size_t                                        bytes,
                                      const managed_seed&                           seed,
                                      hipStream_t                                   stream)
 {
@@ -475,7 +467,7 @@ inline void add_sort_keys_benchmarks(std::vector<benchmark::internal::Benchmark*
 }
 
 inline void add_sort_pairs_benchmarks(std::vector<benchmark::internal::Benchmark*>& benchmarks,
-                                      size_t                                        size,
+                                      size_t                                        bytes,
                                       const managed_seed&                           seed,
                                       hipStream_t                                   stream)
 {
