@@ -24,6 +24,7 @@
 #include <benchmark/benchmark.h>
 
 // rocPRIM
+#include <rocprim/block/block_load.hpp>
 #include <rocprim/block/block_scan.hpp>
 #include <rocprim/device/config_types.hpp>
 #include <rocprim/device/detail/device_config_helper.hpp> // partition_config_params
@@ -208,7 +209,10 @@ inline auto generate_random_data_n(OutputIterator it,
     using T = typename std::iterator_traits<OutputIterator>::value_type;
 
     // Generate floats when T is half
-    using dis_type = std::conditional_t<std::is_same<rocprim::half, T>::value, float, T>;
+    using dis_type = std::conditional_t<std::is_same<rocprim::half, T>::value
+                                            || std::is_same<rocprim::bfloat16, T>::value,
+                                        float,
+                                        T>;
     std::uniform_real_distribution<dis_type> distribution((dis_type)min, (dis_type)max);
     std::generate_n(it, std::min(size, max_random_size), [&]() { return distribution(gen); });
     for(size_t i = max_random_size; i < size; i += max_random_size)
@@ -329,6 +333,50 @@ struct custom_type_decomposer
     }
 };
 
+template<class T, class enable = void>
+struct generate_limits;
+
+template<class T>
+struct generate_limits<T, std::enable_if_t<rocprim::is_integral<T>::value>>
+{
+    static inline T min()
+    {
+        return rocprim::numeric_limits<T>::min();
+    }
+    static inline T max()
+    {
+        return rocprim::numeric_limits<T>::max();
+    }
+};
+
+template<class T>
+struct generate_limits<T, std::enable_if_t<is_custom_type<T>::value>>
+{
+    using F = typename T::first_type;
+    using S = typename T::second_type;
+    static inline T min()
+    {
+        return T(generate_limits<F>::min(), generate_limits<S>::min());
+    }
+    static inline T max()
+    {
+        return T(generate_limits<F>::max(), generate_limits<S>::max());
+    }
+};
+
+template<class T>
+struct generate_limits<T, std::enable_if_t<rocprim::is_floating_point<T>::value>>
+{
+    static inline T min()
+    {
+        return T(-1000);
+    }
+    static inline T max()
+    {
+        return T(1000);
+    }
+};
+
 template<class OutputIterator, class Generator>
 inline auto generate_random_data_n(OutputIterator             it,
                                    size_t                     size,
@@ -400,19 +448,19 @@ auto limit_cast(U value) -> T
     {
         if(value < 0)
         {
-            return std::numeric_limits<T>::min();
+            return rocprim::numeric_limits<T>::min();
         }
         if(static_cast<common_type>(value)
-           > static_cast<common_type>(std::numeric_limits<T>::max()))
+           > static_cast<common_type>(rocprim::numeric_limits<T>::max()))
         {
-            return std::numeric_limits<T>::max();
+            return rocprim::numeric_limits<T>::max();
         }
     }
     else if(rocprim::is_signed<T>::value && rocprim::is_unsigned<U>::value)
     {
-        if(value > std::numeric_limits<T>::max())
+        if(value > rocprim::numeric_limits<T>::max())
         {
-            return std::numeric_limits<T>::max();
+            return rocprim::numeric_limits<T>::max();
         }
     }
     else if(rocprim::is_floating_point<T>::value)
@@ -421,13 +469,13 @@ auto limit_cast(U value) -> T
     }
     else // Both T and U are signed
     {
-        if(value < static_cast<common_type>(std::numeric_limits<T>::min()))
+        if(value < static_cast<common_type>(rocprim::numeric_limits<T>::min()))
         {
-            return std::numeric_limits<T>::min();
+            return rocprim::numeric_limits<T>::min();
         }
-        else if(value > static_cast<common_type>(std::numeric_limits<T>::max()))
+        else if(value > static_cast<common_type>(rocprim::numeric_limits<T>::max()))
         {
-            return std::numeric_limits<T>::max();
+            return rocprim::numeric_limits<T>::max();
         }
     }
     return static_cast<T>(value);
@@ -512,7 +560,7 @@ std::vector<T>
     using key_distribution_type = std::conditional_t<rocprim::is_integral<T>::value,
                                                      std::uniform_int_distribution<dis_type>,
                                                      std::uniform_real_distribution<dis_type>>;
-    key_distribution_type key_distribution(std::numeric_limits<T>::max());
+    key_distribution_type key_distribution(rocprim::numeric_limits<T>::max());
     std::vector<T>        keys(size);
 
     size_t keys_start_index = 0;
@@ -550,6 +598,28 @@ std::vector<T>
     return keys;
 }
 
+template<class T, class U, class V>
+inline auto get_random_value(U min, V max, size_t seed_value)
+    -> std::enable_if_t<rocprim::is_arithmetic<T>::value, T>
+{
+    T           result;
+    engine_type gen(seed_value);
+    generate_random_data_n(&result, 1, min, max, gen);
+    return result;
+}
+
+template<class T>
+inline auto get_random_value(T min, T max, size_t seed_value)
+    -> std::enable_if_t<is_custom_type<T>::value, T>
+{
+    typename T::first_type  result_first;
+    typename T::second_type result_second;
+    engine_type             gen(seed_value);
+    generate_random_data_n(&result_first, 1, min.x, max.x, gen);
+    generate_random_data_n(&result_second, 1, min.y, max.y, gen);
+    return T{result_first, result_second};
+}
+
 template <typename T, T, typename>
 struct make_index_range_impl;
 
@@ -887,6 +957,11 @@ inline const char* Traits<rocprim::half>::name()
     return "rocprim::half";
 }
 template<>
+inline const char* Traits<rocprim::bfloat16>::name()
+{
+    return "rocprim::bfloat16";
+}
+template<>
 inline const char* Traits<long long>::name()
 {
     return "int64_t";
@@ -1058,7 +1133,7 @@ inline void add_common_benchmark_info()
     num("hdp_arch_has_dynamic_parallelism", arch.hasDynamicParallelism);
 }
 
-inline const char* get_block_scan_method_name(rocprim::block_scan_algorithm alg)
+inline const char* get_block_scan_algorithm_name(rocprim::block_scan_algorithm alg)
 {
     switch(alg)
     {
@@ -1068,7 +1143,25 @@ inline const char* get_block_scan_method_name(rocprim::block_scan_algorithm alg)
             return "block_scan_algorithm::reduce_then_scan";
             // Not using `default: ...` because it kills effectiveness of -Wswitch
     }
-    return "unknown_algorithm";
+    return "default_algorithm";
+}
+
+inline const char* get_block_load_method_name(rocprim::block_load_method method)
+{
+    switch(method)
+    {
+        case rocprim::block_load_method::block_load_direct:
+            return "block_load_method::block_load_direct";
+        case rocprim::block_load_method::block_load_striped:
+            return "block_load_method::block_load_striped";
+        case rocprim::block_load_method::block_load_vectorize:
+            return "block_load_method::block_load_vectorize";
+        case rocprim::block_load_method::block_load_transpose:
+            return "block_load_method::block_load_transpose";
+        case rocprim::block_load_method::block_load_warp_transpose:
+            return "block_load_method::block_load_warp_transpose";
+    }
+    return "default_method";
 }
 
 template<std::size_t Size, std::size_t Alignment>
